import React from 'react'
import { Link, useParams } from 'react-router-dom'

import Page from 'components/page'
import { useTranslation } from 'react-i18next'
import {
  Box,
  IconButton,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
  Theme,
  Paper,
} from '@mui/material'
import PersonOutlineRoundedIcon from '@mui/icons-material/PersonOutlineRounded'
import ArrowBackIcon from '@mui/icons-material/ArrowBack'
import { Guest } from 'interfaces'

type GuestInfoParams = {
  pid: string
}
interface RoleLineProps {
  guest: Guest
}

const RoleLine = ({ guest }: RoleLineProps) => {
  const [, i18n] = useTranslation('common')
  return (
    <TableRow
      key={guest.id}
      sx={{ '&:last-child td, &:last-child th': { border: 0 } }}
    >
      <TableCell align="left">
        {i18n.language === 'en' ? guest.role_en : guest.role_nb}
      </TableCell>
      <TableCell component="th" scope="row">
        {guest.period}
      </TableCell>
      <TableCell align="left">
        {i18n.language === 'en' ? guest.ou_en : guest.ou_nb}
      </TableCell>
    </TableRow>
  )
}

interface GuestInfoProps {
  guests: Guest[]
}

export default function GuestInfo({ guests }: GuestInfoProps) {
  const { pid } = useParams<GuestInfoParams>()
  const [t] = useTranslation(['common'])

  const roles = guests.filter((guest) => guest.pid.toString() === pid)
  const guestInfo = roles[0]

  return (
    <Page>
      <Box
        sx={{
          display: 'flex',
          flexDirection: 'row',
          justifyContent: 'center',
          marginBottom: '2rem',
        }}
      >
        <Box>
          <IconButton component={Link} to="/sponsor">
            <ArrowBackIcon />
          </IconButton>
        </Box>
        <Box
          sx={{
            display: 'flex',
            flexDirection: 'column',
            alignItems: 'center',
          }}
        >
          <PersonOutlineRoundedIcon
            fontSize="large"
            sx={{
              borderRadius: '2rem',
              borderStyle: 'solid',
              borderColor: (theme: Theme) => theme.palette.primary.main,
              fill: 'white',
              backgroundColor: (theme: Theme) => theme.palette.primary.main,
            }}
          />
          <Box
            sx={{
              typography: 'caption',
            }}
          >
            {t('sponsor.overviewGuest')}
          </Box>
        </Box>
      </Box>
      <h4>{t('sponsor.contactInfo')}</h4>
      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('sponsor.contactInfo')}</TableCell>
              <TableCell />
            </TableRow>
          </TableHead>
          <TableBody>
            <TableRow>
              <TableCell align="left">{t('input.fullName')}</TableCell>
              <TableCell align="left">{guestInfo.name}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.email')}</TableCell>
              <TableCell align="left">{guestInfo.email}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.nationalIdNumber')}</TableCell>
              <TableCell align="left">{guestInfo.fnr}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.mobilePhone')}</TableCell>
              <TableCell align="left">{guestInfo.mobile}</TableCell>
            </TableRow>
          </TableBody>
        </Table>
      </TableContainer>
      <h4>{t('sponsor.roleInfo')}</h4>
      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('common:role')}</TableCell>
              <TableCell align="left">{t('common:period')}</TableCell>
              <TableCell align="left">{t('common:ou')}</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {roles.map((guest) => (
              <RoleLine guest={guest} />
            ))}
          </TableBody>
        </Table>
      </TableContainer>
    </Page>
  )
}
